// this function verifies disk space in kilobytes
function verifyDiskSpace(dirPath, spaceRequired)
{
  var spaceAvailable;

  // Get the available disk space on the given path
  spaceAvailable = fileGetDiskSpaceAvailable(dirPath);

  // Convert the available disk space into kilobytes
  spaceAvailable = parseInt(spaceAvailable / 1024);

  // do the verification
  if(spaceAvailable < spaceRequired)
  {
    logComment("Spa\u0163iu insuficient pe disc: " + dirPath);
    logComment("  necesar   : " + spaceRequired + " KO");
    logComment("  disponibil: " + spaceAvailable + " KO");
    return(false);
  }

  return(true);
}

// OS type detection
// which platform?
function getPlatform()
{
  var platformStr;
  var platformNode;

  if('platform' in Install)
  {
    platformStr = new String(Install.platform);

    if (!platformStr.search(/^Macintosh/))
      platformNode = 'mac';
    else if (!platformStr.search(/^Win/))
      platformNode = 'win';
    else
      platformNode = 'unix';
  }
  else
  {
    var fOSMac  = getFolder("Mac System");
    var fOSWin  = getFolder("Win System");

    logComment("fOSMac: "  + fOSMac);
    logComment("fOSWin: "  + fOSWin);

    if(fOSMac != null)
      platformNode = 'mac';
    else if(fOSWin != null)
      platformNode = 'win';
    else
      platformNode = 'unix';
  }

  return platformNode;
}


var srDest = 500;
var err;
var fProgram;
var platformNode;

platformNode = getPlatform();
logComment("initInstall: platformNode=" + platformNode);
// end - OS type detection

// --- LOCALIZATION NOTE: translate only these ---
var prettyName = "Limba rom\u00e2n\u0103; (Rom\u00e2nia)";
var langcode = "ro";
var regioncode = "RO";
var chromeNode = langcode + "-" + regioncode;
// --- END LOCALIZABLE RESOURCES ---
var regName    = "locales/mozilla/" + chromeNode;
var chromeName = chromeNode + ".jar";
var regionFile = regioncode + ".jar";
var platformName = langcode + "-" + platformNode + ".jar";
var localeName = "locale/" + chromeNode + "/";
var regionName = "locale/" + regioncode + "/";

err = initInstall(prettyName, regName, "1.2"); 
logComment("initInstall: " + err);

fProgram = getFolder("Program");
logComment("fProgram: " + fProgram);

if (verifyDiskSpace(fProgram, srDest))
{
    var chromeType = LOCALE | DELAYED_CHROME;
    err = addDirectory("","bin",fProgram,"");
    logComment("addDirectory() returned: " + err);

    if (err != SUCCESS)
    {
        logComment("addDirectory() to " + fProgram + "failed!");
 
        // couldn't install globally, try installing to the profile

// seems not to be working with DELAYED_CHROME !?
//        resetError();
//        chromeType |= PROFILE_CHROME;
//        fProgram = getFolder("Profile");
//        logComment("try installing to the user profile:" + fProgram);
//        err = addDirectory("","bin/chrome",fProgram,"chrome");
    }
 
    setPackageFolder(fProgram);
 
    // check return value
    if ((err == SUCCESS) || (err == REBOOT_NEEDED))
    {
        var tellReboot = 0;
        if (err == REBOOT_NEEDED) {
           tellReboot = 1;
           resetError();
        }
        // register chrome
        var cf = getFolder(fProgram, "chrome/"+chromeName);
        var pf = getFolder(fProgram, "chrome/"+platformName);
        var rf = getFolder(fProgram, "chrome/"+regionFile);

        registerChrome(chromeType, cf, localeName + "global/");
        registerChrome(chromeType, cf, localeName + "communicator/");

        registerChrome(chromeType, cf, localeName + "messenger/");
        registerChrome(chromeType, cf, localeName + "editor/");
        registerChrome(chromeType, cf, localeName + "navigator/");
        registerChrome(chromeType, cf, localeName + "necko/");
        registerChrome(chromeType, cf, localeName + "cookie/");
        registerChrome(chromeType, cf, localeName + "wallet/");
        registerChrome(chromeType, cf, localeName + "content-packs/");
        registerChrome(chromeType, cf, localeName + "help/");
        registerChrome(chromeType, cf, localeName + "pipnss/");
        registerChrome(chromeType, cf, localeName + "pippki/");
        registerChrome(chromeType, cf, localeName + "messenger-smime/");
        registerChrome(chromeType, cf, localeName + "mozldap/");
        registerChrome(chromeType, cf, localeName + "autoconfig/");

        registerChrome(chromeType, cf, localeName + "chatzilla/");
//        registerChrome(chromeType, cf, localeName + "venkman/");
//        registerChrome(chromeType, cf, localeName + "inspector/");

        registerChrome(chromeType, pf, localeName + "global-platform/");
        registerChrome(chromeType, pf, localeName + "communicator-platform/");
        registerChrome(chromeType, pf, localeName + "navigator-platform/");
        if(platformNode == 'win')
            registerChrome(chromeType, pf, localeName + "messenger-mapi/");

        registerChrome(chromeType, rf, regionName + "global-region/");
        registerChrome(chromeType, rf, regionName + "communicator-region/");
        registerChrome(chromeType, rf, regionName + "editor-region/");
        registerChrome(chromeType, rf, regionName + "messenger-region/");
        registerChrome(chromeType, rf, regionName + "navigator-region/");

        err = performInstall();
        logComment("performInstall() returned: " + err);
        if (err == SUCCESS)
        {
           if (tellReboot == 1)
           {
               alert("Instalare terminat\u0103. Trebuie s\u0103 v\u0103 REPORNI\u0162I sistemul pentru a putea selecta limba rom\u00e2n\u0103 din meniul Edit > Preferences (panoul Appearance).");
           }
           else
           {
               alert("Instalare terminat\u0103. Dup\u0103 repornirea browser-ului, ve\u0163i putea selecta limba rom\u00e2n\u0103 din meniul Edit > Preferences (panoul Appearance).");
           }
        }
        else
        {
               alert("Instalare e\u015fuat\u0103. Codul de eroare este " + err);
        }
    }
    else
    {
        cancelInstall(err);
        logComment("cancelInstall due to error: " + err);
        if (err == -202) {
           alert("Instalare abandonat\u0103 cu eroarea " + err +". Se pare c\u0103 nu ave\u0163i drepturi de scriere \u00een directorul 'chrome' din Mozilla. V\u0103 rog instala\u0163i cu drepturi de root / administrator de sistem.");
        }
        else {
           alert("Instalare abandonat\u0103. Codul de eroare este " + err);
        }
    }
}
else
    cancelInstall(INSUFFICIENT_DISK_SPACE);


